<?php
/**
 * Plugin Name: EasyToolsWP Custom Search Descriptions
 * Description: Display custom descriptions for specific search terms under the H1 title in WooCommerce search results.
 * Version: 1.3
 * Author: EasyTools.com
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

// Register custom post type for search terms
function cstd_register_search_term_cpt() {
    $labels = array(
        'name'               => 'Search Terms',
        'singular_name'      => 'Search Term',
        'menu_name'          => 'Search Terms',
        'name_admin_bar'     => 'Search Term',
        'add_new'            => 'Add New',
        'add_new_item'       => 'Add New Search Term',
        'new_item'           => 'New Search Term',
        'edit_item'          => 'Edit Search Term',
        'view_item'          => 'View Search Term',
        'all_items'          => 'All Search Terms',
        'search_items'       => 'Search Search Terms',
        'not_found'          => 'No search terms found.',
    );
    
    $args = array(
        'labels'             => $labels,
        'public'             => false,
        'show_ui'            => true,
        'show_in_menu'       => true,
        'query_var'          => true,
        'rewrite'            => array( 'slug' => 'search-term' ),
        'capability_type'    => 'post',
        'has_archive'        => false,
        'hierarchical'       => false,
        'menu_position'      => 20,
        'supports'           => array( 'title', 'editor' ),
    );
    
    register_post_type( 'search_term', $args );
}
add_action( 'init', 'cstd_register_search_term_cpt' );

// Display custom description under H1 on WooCommerce search result pages
function cstd_display_custom_search_description() {
    if ( is_search() && is_shop() ) {
        // Get the search query (what the user searched for)
        $search_term = get_search_query();

        // Query the custom post type for a matching search term
        $args = array(
            'post_type'      => 'search_term',
            'title'          => $search_term,
            'post_status'    => 'publish',
            'posts_per_page' => 1,
        );
        
        $custom_search_term = new WP_Query( $args );

        // If a matching search term is found, display its description
        if ( $custom_search_term->have_posts() ) {
            while ( $custom_search_term->have_posts() ) {
                $custom_search_term->the_post();

                // Output the custom description under the H1 title
                echo '<div class="custom-search-description" style="margin-bottom: 20px;">';
                echo '<p>' . get_the_content() . '</p>';
                echo '</div>';
            }
            wp_reset_postdata();
        }
    }
}
add_action( 'woocommerce_before_main_content', 'cstd_display_custom_search_description', 15 );
